<?php
namespace Teknisa\Repositories;

use Setforms2\Shared\Registry;

class SitProdutoint extends \Doctrine\ORM\EntityRepository
{
    /**
     * Busca os produtos liberados pela Teknisa, cuja integração já foi realizada,
     * para que sejam enviados de volta ao banco do Cliente.
     *
     * @param String $nrorg    Organização
     * @param String $nrorgint Organização Integração
     *
     * @return array.
     */
    public static function sqlProdutosLiberados ($nrorg, $nrorgint)
    {
        $sql = <<<SQL
            SELECT *
            FROM SIT_PRODUTOINT
            WHERE ((SIT_PRODUTOINT.DTLIBERACAO IS NOT NULL
               OR SIT_PRODUTOINT.IDATIVO       = 'N')
              AND SIT_PRODUTOINT.DTENVIO       IS NULL)
              AND SIT_PRODUTOINT.NRORG         = '$nrorg'
              AND SIT_PRODUTOINT.NRORGINT      = '$nrorgint'
            ORDER BY SIT_PRODUTOINT.NMPRODUTOINT
SQL;

        $entityManager = Registry::getEntityManager();
        $result = $entityManager->getConnection()->fetchAll($sql);
        return $result;
    }

    /**
     * Busca Produtos pelas PKs
     *
     * @param String $nrorg     Organização
     * @param String $nrorgint  Organização de Integração
     * @param String $nrremessa Remessa
     *
     * @return array.
     */
    public static function sqlBuscaProdutos ($nrorg, $nrorgint, $nrremessa)
    {
        $sql = <<<SQL
                  SELECT *
                  FROM SIT_PRODUTOINT
                  WHERE NRORG   = :P_NRORG
                  AND NRORGINT  = :P_NRORGINT
                  AND NRREMESSA = :P_NRREMESSA
SQL;

        $params = array(
            "P_NRORG" => $nrorg, "P_NRORGINT" => $nrorgint,
            "P_NRREMESSA" => $nrremessa
        );

        $entityManager = Registry::getEntityManager();
        $result = $entityManager->getConnection()->fetchAll($sql, $params);
        return $result;
    }

    /**
     * Busca Produtos Pendentes
     *
     * @param String $nrorg     Organização
     * @param String $nrorgint  Organização de Integração
     * @param String $nrremessa Remessa Pendente
     *
     * @return array.
     */
    public static function sqlBuscaProdutosPendentes ($nrorg, $nrorgint, $nrremessa)
    {
        $sql = <<<SQL
                  SELECT *
                    FROM SIT_PRODUTOINT
                    JOIN SIT_LOGTEK
                    ON SIT_PRODUTOINT.NRREMESSA = SIT_LOGTEK.NRREMESSAORI
                    AND SIT_PRODUTOINT.NRORG = SIT_LOGTEK.NRORG
                    AND SIT_PRODUTOINT.CDPRODUTOINT = SIT_LOGTEK.CDPRODUTOINT
                    WHERE SIT_PRODUTOINT.NRORG      = :P_NRORG
                    AND SIT_PRODUTOINT.NRORGINT     = :P_NRORGINT
                    AND SIT_LOGTEK.NRREMESSAINT     = :P_NRREMESSA
                    ORDER BY SIT_PRODUTOINT.NMPRODUTOINT
SQL;

        $params = array(
            "P_NRORG" => $nrorg, "P_NRORGINT" => $nrorgint,
            "P_NRREMESSA" => $nrremessa
        );

        $entityManager = Registry::getEntityManager();
        $result = $entityManager->getConnection()->fetchAll($sql, $params);
        return $result;
    }
}